@@ -146,7 +146,8 @@ func (callCtx *callContext) doReturn(ret *Variable, err error) {
 // EvalExpressionWithCalls is like EvalExpression but allows function calls in 'expr'.
 // Because this can only be done in the current goroutine, unlike
 // EvalExpression, EvalExpressionWithCalls is not a method of EvalScope.
-func EvalExpressionWithCalls(t *Target, g *G, expr string, retLoadCfg LoadConfig, checkEscape bool) error {
+func EvalExpressionWithCalls(grp *TargetGroup, g *G, expr string, retLoadCfg LoadConfig, checkEscape bool) error {
+	t := grp.Selected
 	bi := t.BinInfo()
 	if !t.SupportsFunctionCalls() {
 		return errFuncCallUnsupportedBackend
@@ -201,7 +202,7 @@ func EvalExpressionWithCalls(t *Target, g *G, expr string, retLoadCfg LoadConfig
 
 	contReq, ok := <-continueRequest
 	if contReq.cont {
-		return t.Continue()
+		return grp.Continue()
 	}
 
 	return finishEvalExpressionWithCalls(t, g, contReq, ok)
@@ -1044,7 +1045,7 @@ func readStackVariable(t *Target, thread Thread, regs Registers, off uint64, typ
 	return v, nil
 }
 
-// fakeEntryScope alters scope to pretend that we are at the entry point of
+// fakeFunctionEntryScope alters scope to pretend that we are at the entry point of
 // fn and CFA and SP are the ones passed as argument.
 // This function is used to create a scope for a call frame that doesn't
 // exist anymore, to read the return variables of an injected function call,
